-------
Bowline
-------

Configurable tools to easily pre and post process your data for data-science and machine learning.

=============
Why the name?
=============
As data is quite hard to "wrangle" I thought what'd be better to use then the name of a knot. So here we are, Bowline is a tool made for all your data wrangling needs.
